# Copyright (C) 2014 Harald Eilertsen
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

module SalesReporter
  module Reports
    class SalesByDate
      def initialize
        @sales = []
      end

      def add_sale(sale, row)
        @sales << sale
      end

      def render
        sales_by_date = {}

        @sales.each do |s|
          d = s.date
          if sales_by_date[d]
            sales_by_date[d][:count] += s.quantity
            sales_by_date[d][:total] += s.amount
          else
            sales_by_date[d] = {:count => s.quantity, :total => s.amount}
          end
        end

        puts "Date:       Streams:  Revenue:"
        puts "------------------------------------------"

        total_rev = 0
        total_streams = 0

        sales_by_date.each do |key, row|
          puts "#{key.iso8601}: #{row[:count].to_s.rjust(7)} #{row[:total].round(5).to_s.rjust(10)} EUR"
          total_rev += row[:total]
          total_streams += row[:count]
        end

        puts "------------------------------------------"
        puts "Total:      #{total_streams.to_s.rjust(7)} #{total_rev.round(5).to_s.rjust(10)} EUR"
        puts "=========================================="
      end
    end
  end
end
