# Parse Sales Reports from iMusicianDigital
# Copyright (C) 2014 Harald Eilertsen
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

require_relative 'lib/sale'
require 'csv'

def parse_csv(csv_file)
  csv_opts = {
    :col_sep => ";",
    :skip_lines => /^(Notes|The |;)/,
    :headers => true,
    :converters => :all,
  }

  CSV.foreach(csv_file, csv_opts) do |row|
    if row.count > 0
      yield row
    end
  end
end

def load_reports
  Dir[File.join('lib', 'reports', '*.rb')].each do |f|
    require_relative f
  end

  SalesReporter::Reports.constants.map do |report|
    SalesReporter::Reports.const_get(report).new
  end
end

reports = load_reports

parse_csv(ARGV[0]) do |row|
  sale = SalesReporter::Sale.new(row["Date"], row["revenue EUR"], row["quantity"])
  reports.each { |r| r.add_sale(sale, row) }
end

reports.each do |report|
  report.render
  puts "\n"
end
